@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2004, 2009, 2012 Vidyut Samanta and Christian Grothoff
+     Copyright (C) 2004, 2009, 2012 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with libextractor; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 
      This code was based on AVInfo 1.0 alpha 11
      (c) George Shuklin, gs]AT[shounen.ru, 2002-2004
